==> AsposeCellsCloud-CellsApi-23.8.tar.gz: AsposeCellsCloud-CellsApi-23.8/docs/RadioButton.md <==
# AsposeCellsCloud::Object::RadioButton 

## Load the model package
```perl
use AsposeCellsCloud::Object::RadioButton;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**GroupBox** | **GroupBox** |  |
**IsChecked** | **boolean** |  |
**Shadow** | **boolean** |  |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-24.4.tar.gz: AsposeCellsCloud-CellsApi-24.4/docs/RadioButton.md <==
# AsposeCellsCloud::Object::RadioButton 

## Load the model package
```perl
use AsposeCellsCloud::Object::RadioButton;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**GroupBox** | **GroupBox** | Gets the GroupBox that contains this RadioButton. |
**IsChecked** | **boolean** | Indicates if the radiobutton is checked or not. |
**Shadow** | **boolean** | Indicates whether the combobox has 3-D shading. |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
